.. coolname documentation master file, created by
   sphinx-quickstart on Sat Apr 23 13:03:36 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. toctree::
   :maxdepth: 2
   :hidden:

   Introduction <self>
   customization
   environment-variables
   randomization
   classes-and-functions
   thread-safe
   history

.. include:: ../README.rst
